@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw($VERSION @ISA $__import @preload $pid);
 @ISA = qw(DynaLoader);
 sub dl_load_flags { 0x00 }
-$VERSION = '1.71_12';
+$VERSION = '1.72_1';
 $pid = $$;
 bootstrap Prima $VERSION;
 unless ( UNIVERSAL::can('Prima', 'init')) {
@@ -528,13 +528,15 @@ L<Prima::Image::Animate> - animate gif and webp files
 
 L<Prima::Image::base64> - hardcoded image files
 
+L<Prima::Image::Exif> - manipulate Exif records
+
 L<Prima::Image::Loader> - progressive loading and saving for multiframe images
 
 L<Prima::IniFile> - support of Windows-like initialization files
 
 L<podview> - POD viewer
 
-L<pod2pdf> - POD printer
+L<prima-pod2pdf> - POD printer
 
 L<Prima::StdBitmap> - shared access to the standard bitmaps
 
@@ -577,7 +579,7 @@ standard Prima documentation viewer C<podview> ( see File/Run/prima-class ).
 Copyright 1997-2003 The Protein Laboratory, University of Copenhagen. All
 rights reserved.
 
-Copyright 2004-2023 Dmitry Karasik. All rights reserved.
+Copyright 2004-2024 Dmitry Karasik. All rights reserved.
 
 This program is distributed under the BSD License.
 
